<?php
namespace Claromentis\Projects\Controller;

$GLOBALS["__65da1b1ec2d6653e8a0ab7" . "848e536215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab7848e5362" . "15"] ?: array()) + array("statuse" . "s" => base64_decode("c3RhdHVzZXM" . "="), "_8f4004bb" . "39963606d" . "042524caf" . "b2c56e" => base64_decode("Tm8gbmFtZSBnaXZlb" . "g=="), "_f4afc0b7f428996" . "9aa2dc5100728731" . "f" => base64_decode("cHJvamVjdHMucmVz" . "dC5ub19wcm9qZWN0"), "_80f432640c97e2aa41266" . "4c408f72221" => base64_decode("Q2Fubm90IGRlbGV" . "0ZSBpbml0aWFsIH" . "N0YXR1cw=="), "_0ea4e32b5796" . "3ac0cb3057e03" . "e9aef64" => base64_decode("aW" . "Q="), "statu" . "s" => base64_decode("c3Rh" . "dHVz"), "_8dabb06efc95df4cff7c4afe91857b5" . "3" => base64_decode("bmFt" . "ZQ=="), "_a29b27c98290e926d8b084b48c9ce36" . "9" => base64_decode("WW91IGRvIG5vdCBoYXZlIHBlcm1pc" . "3Npb24gdG8gZWRpdCB0aGUgbGlzdC" . "BvZiBzdGF0dXNlcw=="), "_f33594668a14ecd5ed" . "e1fb90b8354c70" => base64_decode("TmV3IHN0Y" . "XR1cyBtdX" . "N0IGhhdmU" . "gbmFtZQ=="), "_f805302e3f25df291" . "a3dd8ea386da8a4" => base64_decode("IGluIHByb2plY3" . "Qg"), "_9ed84d2923d81db" . "75e6348d1b290c05" . "1" => base64_decode("Y29tcGxldGVkX3" . "N0YXR1c19sYWJl" . "bA=="), "_b94c0530a0fc19421865e1efa" . "5f6779f" => base64_decode("Tm8gc3RhdHVzIEl" . "EIA=="), "_7d5f0a31f61b7b73" . "4f21a9bf6acf2502" => base64_decode("Q2Fubm90IGRlbGV0ZSBmaW5hbCBzdGF0" . "dXM="), "_068ab9b9340314c5b07" . "e3e5cc31d925b" => base64_decode("c29ydF9" . "vcmRlcg" . "=="), "_5f4d1ad89c941500471" . "a8370398dad9e" => base64_decode("dG9kb19zdGF0dXNfbGFiZ" . "Ww="), "_4d23892ff91aa3195a85bb548a7" . "f4333" => base64_decode("bG9jYWxpemVkX25hbWU" . "="));
use Analogue\ORM\Exceptions\MappingException;
use Claromentis\Core\CDN;
use Claromentis\Core\Http\JsonPrettyResponse;
use Claromentis\Core\Localization\Lmsg;
use Claromentis\Core\REST\RestFormatter;
use Claromentis\Projects\Entity\TaskStatus;
use Claromentis\Projects\Exceptions\StatusStorageException;
use Claromentis\Projects\Model\Task;
use Claromentis\Projects\Permissions;
use Claromentis\Projects\PermissionsChecker;
use Claromentis\Projects\Repository\ProjectRepository;
use Claromentis\Projects\TaskStatusApi;
use Psr\Http\Message\ServerRequestInterface;
class TaskStatusController
{
    
    
    
    
    protected $api;
    
    
    
    
    protected $project_provider;
    
    
    
    
    protected $formatter;
    
    
    
    
    protected $lmsg;
    public function __construct(TaskStatusApi $api, ProjectRepository $project_provider, RestFormatter $formatter, Lmsg $lmsg)
    {
        $this->api = $api;
        $this->project_provider = $project_provider;
        $this->formatter = $formatter;
        $this->lmsg = $lmsg;
    }
    
    
    
    
    
    
    
    
    public function ShowList(int $project_id) : JsonPrettyResponse
    {
        $project = $this->project_provider->GetProject($project_id);
        if (!$project) {
            throw new \RestExNotFound(($this->lmsg)($GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"]["_f4afc0b7" . "f4289969a" . "a2dc51007" . "28731f"]));
        }
        $statuses = $this->api->getProjectStatuses($project)->all();
        return new JsonPrettyResponse([[$GLOBALS["__65da1b1ec2d6653e8a0ab7848" . "e536215"]["statuse" . "s"] => $this->FormatStatuses($statuses)]]);
    }
    
    
    
    
    
    
    
    
    
    public function Show(int $project_id, TaskStatus $status) : JsonPrettyResponse
    {
        $this->CheckProjectId($project_id, $status);
        return new JsonPrettyResponse([$GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"]["stat" . "us"] => $this->FormatStatus($status)]);
    }
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    public function Update(int $project_id, TaskStatus $status, ServerRequestInterface $_b791059c94b285cdf1c90ca6f3a8f2a6, PermissionsChecker $permissions_checker) : JsonPrettyResponse
    {
        $this->CheckProjectId($project_id, $status);
        $this->CheckEditPermissions($project_id, $permissions_checker);
        $_231341bedbbeea0ba9fa8da63ef63dc1 = $status->id === 0;
        $_a71dc9333bd8ad95d55d6624b477875f = $this->formatter->GetJson($_b791059c94b285cdf1c90ca6f3a8f2a6);
        $_9bacb470d4f91e74f3caafec23aeca8e = clone $status;
        if ($_231341bedbbeea0ba9fa8da63ef63dc1) {
            $status->project_id = $project_id;
            if (empty($_a71dc9333bd8ad95d55d6624b477875f[$GLOBALS["__65da1b1ec2d6653e" . "8a0ab7848e536215"]["_8dabb06efc95df4cff7c4af" . "e91857b53"]])) {
                throw new \RestExBadRequest($GLOBALS["__65da1b1ec2d6653e8" . "a0ab7848e536215"]["_f33594668a14ecd" . "5ede1fb90b8354c7" . "0"]);
            }
        }
        $status->sort_order = $_a71dc9333bd8ad95d55d6624b477875f[$GLOBALS["__65da1b1ec2d6653e8a0ab7848" . "e536215"]["_068ab9b9340314" . "c5b07e3e5cc31d9" . "25b"]] ?? $status->sort_order;
        $status->name = $_a71dc9333bd8ad95d55d6624b477875f[$GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"]["_8dabb06efc95df4cff7c4" . "afe91857b53"]] ?? $status->name;
        $this->api->SaveStatus($status);
        if ($_231341bedbbeea0ba9fa8da63ef63dc1) {
            $this->api->StatusAddedHistory($status);
        } else {
            $this->api->StatusUpdatedHistory($_9bacb470d4f91e74f3caafec23aeca8e, $status);
        }
        return new JsonPrettyResponse([$GLOBALS["__65da1b1ec2d6653e8" . "a0ab7848e536215"]["stat" . "us"] => $this->FormatStatus($status)], $_231341bedbbeea0ba9fa8da63ef63dc1 ? 201 : 200);
    }
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    public function UpdateV3(int $project_id, TaskStatus $status, ServerRequestInterface $_b791059c94b285cdf1c90ca6f3a8f2a6, PermissionsChecker $permissions_checker) : JsonPrettyResponse
    {
        $this->CheckProjectId($project_id, $status);
        $this->CheckEditPermissions($project_id, $permissions_checker);
        $_231341bedbbeea0ba9fa8da63ef63dc1 = $status->id === 0;
        $_a71dc9333bd8ad95d55d6624b477875f = $this->formatter->GetJson($_b791059c94b285cdf1c90ca6f3a8f2a6);
        $_9bacb470d4f91e74f3caafec23aeca8e = clone $status;
        if ($_231341bedbbeea0ba9fa8da63ef63dc1) {
            $status->project_id = $project_id;
            if (empty($_a71dc9333bd8ad95d55d6624b477875f[$GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"]["_8dabb06efc95df4cff7c4afe9" . "1857b53"]])) {
                throw new \RestExBadRequest($GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"]["_f33594668a14ecd5" . "ede1fb90b8354c70"]);
            }
        }
        $status->sort_order = $_a71dc9333bd8ad95d55d6624b477875f[$GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"]["_068ab9b9340314c5b07e3e5cc31d9" . "25b"]] ?? $status->sort_order;
        $status->name = $_a71dc9333bd8ad95d55d6624b477875f[$GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"]["_8dabb06efc95df" . "4cff7c4afe91857" . "b53"]] ?? $status->name;
        $this->api->SaveStatus($status);
        if ($_231341bedbbeea0ba9fa8da63ef63dc1) {
            $this->api->StatusAddedHistory($status);
        } else {
            $this->api->StatusUpdatedHistory($_9bacb470d4f91e74f3caafec23aeca8e, $status);
        }
        $_1833c1908972ebd0c77f861e80c2d9bf = $this->api->getProjectStatuses($project_id);
        return new JsonPrettyResponse([$GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"]["statu" . "s"] => $this->FormatStatus($status), $GLOBALS["__65da1b1ec2d6653e" . "8a0ab7848e536215"]["status" . "es"] => $this->FormatStatuses($_1833c1908972ebd0c77f861e80c2d9bf)], $_231341bedbbeea0ba9fa8da63ef63dc1 ? 201 : 200);
    }
    
    
    
    
    
    
    
    
    
    
    
    
    public function Delete(int $project_id, TaskStatus $status, PermissionsChecker $permissions_checker) : JsonPrettyResponse
    {
        $this->CheckProjectId($project_id, $status);
        $this->CheckEditPermissions($project_id, $permissions_checker);
        $this->api->DeleteStatus($status);
        return new JsonPrettyResponse([$GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"]["stat" . "us"] => $this->FormatStatus($status)]);
    }
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    public function DeleteV3(int $project_id, TaskStatus $status, PermissionsChecker $permissions_checker) : JsonPrettyResponse
    {
        $this->CheckProjectId($project_id, $status);
        $this->CheckEditPermissions($project_id, $permissions_checker);
        $this->api->DeleteStatus($status);
        $_1833c1908972ebd0c77f861e80c2d9bf = $this->api->getProjectStatuses($project_id);
        return new JsonPrettyResponse([$GLOBALS["__65da1b1ec2d6653e8a" . "0ab7848e536215"]["stat" . "us"] => $this->FormatStatus($status), $GLOBALS["__65da1b1ec2d6653e8" . "a0ab7848e536215"]["stat" . "uses"] => $this->FormatStatuses($_1833c1908972ebd0c77f861e80c2d9bf)]);
    }
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    public function UpdateTodo(PermissionsChecker $permissions_checker, int $project_id, ServerRequestInterface $_b791059c94b285cdf1c90ca6f3a8f2a6) : JsonPrettyResponse
    {
        $this->CheckEditPermissions($project_id, $permissions_checker);
        $project = $this->project_provider->GetProject($project_id);
        $_ed5f03d686c37933b5943f295c6b4a43 = $this->formatter->GetJson($_b791059c94b285cdf1c90ca6f3a8f2a6);
        if (!$project) {
            throw new \RestExBadRequest(($this->lmsg)($GLOBALS["__65da1b1ec2d6653e8a0ab7" . "848e536215"]["_f4afc0b7f4289969aa2dc510072" . "8731f"]));
        }
        if (!isset($_ed5f03d686c37933b5943f295c6b4a43[$GLOBALS["__65da1b1ec2" . "d6653e8a0ab7" . "848e536215"]["_8dabb06efc95df4cff7c" . "4afe91857b53"]])) {
            throw new \RestExBadRequest($GLOBALS["__65da1b1ec2d6653e8" . "a0ab7848e536215"]["_8f4004bb39963606" . "d042524cafb2c56e"]);
        }
        $project->SetProperty($GLOBALS["__65da1b1ec2d665" . "3e8a0ab7848e5362" . "15"]["_5f4d1ad89c941500471a8370" . "398dad9e"], $_ed5f03d686c37933b5943f295c6b4a43[$GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"]["_8dabb06efc95df4cff7c4afe9185" . "7b53"]]);
        $this->project_provider->SaveProject($project);
        return new JsonPrettyResponse([$GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"]["sta" . "tus"] => [$GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"]["_0ea4e32b57963ac0cb3057e03e9a" . "ef64"] => Task::STATUS_TODO, $GLOBALS["__65da1b1ec2d6653" . "e8a0ab7848e536215"]["_8dabb06efc95df" . "4cff7c4afe91857" . "b53"] => $_ed5f03d686c37933b5943f295c6b4a43[$GLOBALS["__65da1b1ec2d6653e8a0ab7848e53" . "6215"]["_8dabb06efc95df4cff7" . "c4afe91857b53"]], $GLOBALS["__65da1b1ec2d6653e8" . "a0ab7848e536215"]["_4d23892ff91aa3195a85bb548a" . "7f4333"] => $this->lmsg->lmsg_str($_ed5f03d686c37933b5943f295c6b4a43[$GLOBALS["__65da1b1ec2d6" . "653e8a0ab7848e" . "536215"]["_8dabb06efc95d" . "f4cff7c4afe918" . "57b53"]])]]);
    }
    public function DeleteTodo()
    {
        throw new \RestExBadRequest($GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"]["_80f432640c97e2aa412664c408" . "f72221"]);
    }
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    public function UpdateCompleted(PermissionsChecker $permissions_checker, int $project_id, ServerRequestInterface $_b791059c94b285cdf1c90ca6f3a8f2a6) : JsonPrettyResponse
    {
        $this->CheckEditPermissions($project_id, $permissions_checker);
        $project = $this->project_provider->GetProject($project_id);
        $_ed5f03d686c37933b5943f295c6b4a43 = $this->formatter->GetJson($_b791059c94b285cdf1c90ca6f3a8f2a6);
        if (!$project) {
            throw new \RestExBadRequest(($this->lmsg)($GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"]["_f4afc0b7f" . "4289969aa2" . "dc51007287" . "31f"]));
        }
        if (!isset($_ed5f03d686c37933b5943f295c6b4a43[$GLOBALS["__65da1b1ec2d6653e8a0ab" . "7848e536215"]["_8dabb06efc" . "95df4cff7c4" . "afe91857b53"]])) {
            throw new \RestExBadRequest($GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"]["_8f4004bb39963606d" . "042524cafb2c56e"]);
        }
        $project->SetProperty($GLOBALS["__65da1b1ec2d6653e8" . "a0ab7848e536215"]["_9ed84d2923d81db75e6348d1b2" . "90c051"], $_ed5f03d686c37933b5943f295c6b4a43[$GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"]["_8dabb06efc95df4cff7c4" . "afe91857b53"]]);
        $this->project_provider->SaveProject($project);
        return new JsonPrettyResponse([$GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"]["st" . "at" . "us"] => [$GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"]["_0ea4e32b57963ac0cb305" . "7e03e9aef64"] => Task::STATUS_COMPLETED, $GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"]["_8dabb06" . "efc95df4" . "cff7c4af" . "e91857b5" . "3"] => $_ed5f03d686c37933b5943f295c6b4a43[$GLOBALS["__65da1b1ec2d6653e8a0ab" . "7848e536215"]["_8dabb06efc95df4cff7c4afe91857" . "b53"]], $GLOBALS["__65da1b1ec2d6653e8a0ab7848e5362" . "15"]["_4d23892ff91aa3195a" . "85bb548a7f4333"] => $this->lmsg->lmsg_str($_ed5f03d686c37933b5943f295c6b4a43[$GLOBALS["__65da1b1ec2d6653e8a0ab7848" . "e536215"]["_8dabb06efc95df4c" . "ff7c4afe91857b53"]])]]);
    }
    public function DeleteCompleted()
    {
        throw new \RestExBadRequest($GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"]["_7d5f0a31f61b7b734" . "f21a9bf6acf2502"]);
    }
    
    
    
    
    
    
    
    private function CheckEditPermissions(int $project_id, PermissionsChecker $permissions_checker)
    {
        if (!$permissions_checker->CanI($project_id, Permissions::EDIT_PROJECT_PROPERTIES)) {
            throw new \RestExForbidden($GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"]["_a29b27c98290e926d8b08" . "4b48c9ce369"]);
        }
    }
    
    
    
    
    
    
    
    private function CheckProjectId(int $project_id, TaskStatus $status)
    {
        if ($status->project_id && $project_id !== $status->project_id) {
            throw new \RestExNotFound($GLOBALS["__65da1b1ec2d6653e8a0ab7848e536" . "215"]["_b94c0530a0fc19421865e1ef" . "a5f6779f"] . $status->id . $GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"]["_f805302e3f25df291a3dd" . "8ea386da8a4"] . $project_id);
        }
    }
    private function FormatStatuses($statuses) : array
    {
        $_e8180e518b009dc0ea8c578fe193c4ae = [];
        
        
        foreach ($statuses as $status) {
            $_e8180e518b009dc0ea8c578fe193c4ae[] = $this->FormatStatus($status);
        }
        return $_e8180e518b009dc0ea8c578fe193c4ae;
    }
    
    
    
    
    
    
    private function FormatStatus(TaskStatus $status) : array
    {
        $status = $status->toArray();
        $status[$GLOBALS["__65da1b1ec2" . "d6653e8a0ab7" . "848e536215"]["_4d23892" . "ff91aa31" . "95a85bb5" . "48a7f433" . "3"]] = $this->lmsg->lmsg_str($status[$GLOBALS["__65da1b1ec2d6653e8a" . "0ab7848e536215"]["_8dabb06efc95df4cff7c4a" . "fe91857b53"]]);
        return $status;
    }
}